/*
 *	file : multbyte.c
 */

#include "vim.h"
#include "globals.h"
#include "proto.h"
#include "option.h"
#ifdef WIN32
# include <windows.h>
#endif

/* Is 'c' a lead byte of multi-byte character? */
int IsLeadByte(char_u c)
{
#ifdef WIN32
    return IsDBCSLeadByte(c);
#else
    return (c & 0x80);
#endif
}

/* Is *p a trail byte of multi-byte character?
   base : string pointer to line */
int IsTrailByte( char *base, char *p )
{
    int lbc = 0;    /* lead byte count*/

	if ( base >= p )
		return 0;

    while ( p > base ) {
	if ( !IsLeadByte(*(--p)) )
	    break;
	lbc++;
    }

    return (lbc & 1);
}

/* 
   if the cursor moves on an trail byte,
   set the cursor on the lead byte.
*/
int AdjustCursorForMultiByteCharacter(void) {

    if ( curwin->w_cursor.col > 0 ) {
        char_u *p;
        p = ml_get(curwin->w_cursor.lnum);
        if ( IsTrailByte(p, p + curwin->w_cursor.col ) ) {
            --curwin->w_cursor.col;
            return 1;
        }
    }
    return 0;
}
       
